@@ -2,8 +2,8 @@ use strict;
 use warnings;
 
 package IMS::CP::Manifest;
-BEGIN {
-  $IMS::CP::Manifest::VERSION = '0.0.2';
+{
+  $IMS::CP::Manifest::VERSION = '0.0.3';
 }
 use Moose;
 with 'XML::Rabbit::RootNode';
@@ -39,8 +39,8 @@ __PACKAGE__->meta->make_immutable();
 
 1;
 
-
 __END__
+
 =pod
 
 =encoding utf-8
@@ -51,7 +51,7 @@ IMS::CP::Manifest - IMS Content Packaging Manifest XML parser
 
 =head1 VERSION
 
-version 0.0.2
+version 0.0.3
 
 =head1 DESCRIPTION
 
@@ -76,27 +76,52 @@ The main title of the manifest.
 A list of organizations of content. Organizations are basically different
 ways to organize the content in the package, e.g. linear or hierarchial.
 
-=for :stopwords CPAN AnnoCPAN RT CPANTS Kwalitee diff
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
+=head2 Perldoc
+
 You can find documentation for this module with the perldoc command.
 
   perldoc IMS::CP::Manifest
 
 =head2 Websites
 
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
 =over 4
 
 =item *
 
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/IMS-CP-Manifest>
+
+=item *
+
 Search CPAN
 
+The default CPAN search engine, useful to view POD in HTML format.
+
 L<http://search.cpan.org/dist/IMS-CP-Manifest>
 
 =item *
 
-AnnoCPAN: Annotated CPAN documentation
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=IMS-CP-Manifest>
+
+=item *
+
+AnnoCPAN
+
+The AnnoCPAN is a website that allows community annotations of Perl module documentation.
 
 L<http://annocpan.org/dist/IMS-CP-Manifest>
 
@@ -104,66 +129,77 @@ L<http://annocpan.org/dist/IMS-CP-Manifest>
 
 CPAN Ratings
 
+The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
+
 L<http://cpanratings.perl.org/d/IMS-CP-Manifest>
 
 =item *
 
 CPAN Forum
 
+The CPAN Forum is a web forum for discussing Perl modules.
+
 L<http://cpanforum.com/dist/IMS-CP-Manifest>
 
 =item *
 
-RT: CPAN's Bug Tracker
+CPANTS
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=IMS-CP-Manifest>
-
-=item *
-
-CPANTS Kwalitee
+The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
 L<http://cpants.perl.org/dist/overview/IMS-CP-Manifest>
 
 =item *
 
-CPAN Testers Results
+CPAN Testers
 
-L<http://cpantesters.org/distro/I/IMS-CP-Manifest.html>
+The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+
+L<http://www.cpantesters.org/distro/I/IMS-CP-Manifest>
 
 =item *
 
 CPAN Testers Matrix
 
+The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+
 L<http://matrix.cpantesters.org/?dist=IMS-CP-Manifest>
 
 =item *
 
-Source Code Repository
+CPAN Testers Dependencies
+
+The CPAN Testers Dependencies is a website that shows a chart of the test results of all dependencies for a distribution.
+
+L<http://deps.cpantesters.org/?module=IMS::CP::Manifest>
+
+=back
+
+=head2 Bugs / Feature Requests
+
+Please report any bugs or feature requests by email to C<bug-ims-cp-manifest at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IMS-CP-Manifest>. You will be automatically notified of any
+progress on the request by the system.
+
+=head2 Source Code
 
 The code is open to the world, and available for you to hack on. Please feel free to browse it and play
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<git://github.com/robinsmidsrod/IMS-CP-Manifest.git>
+L<http://github.com/robinsmidsrod/IMS-CP-Manifest>
 
-=back
-
-=head2 Bugs
-
-Please report any bugs or feature requests to C<bug-ims-cp-manifest at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=IMS-CP-Manifest>.  I will be
-notified, and then you'll automatically be notified of progress on your bug as I make changes.
+  git clone git://github.com/robinsmidsrod/IMS-CP-Manifest.git
 
 =head1 AUTHOR
 
-  Robin Smidsrød <robin@smidsrod.no>
+Robin Smidsrød <robin@smidsrod.no>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Robin Smidsrød.
+This software is copyright (c) 2013 by Robin Smidsrød.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
